module.exports = defineTest({
	description: 'does not rename undefined'
});
